@@ -6,7 +6,8 @@ import sys
 import urllib
 import webbrowser
 import subprocess
-from os import listdir, path, system
+from os import listdir, path, system, environ
+
 
 import simplejson
 
@@ -17,10 +18,16 @@ from github import GitHub
 class Bat(object):
 
     CURR_SCRIPT = ''
-    PATHOGEN_URL = 'http://github.com/vim-scripts/pathogen.vim/raw/master/plugin/pathogen.vim'
     VIM_PATH = path.join(path.expanduser('~'), '.vim')
     AUTOLOAD_PATH = path.join(VIM_PATH, 'autoload')
     VIMPYRE_PATH = path.join(VIM_PATH, 'vimpyre')
+    
+    @property
+    def pathogen_url(self):
+        try:
+            return environ['VIM_PATHOGEN_URL']
+        except:
+            return 'https://raw.github.com/tpope/vim-pathogen/master/autoload/pathogen.vim'
 
     def __init__(self, script = ''):
         self.CURR_SCRIPT = script
@@ -72,7 +79,7 @@ class Bat(object):
         """
         try:
             console('=> => Send a bat to catch pathogen.vim ...')
-            raw_urlopen = urllib.urlopen(self.PATHOGEN_URL)
+            raw_urlopen = urllib.urlopen(self.pathogen_url)
             if raw_urlopen.getcode() == 200:
                 util.mkdir_p(self.AUTOLOAD_PATH)
                 util.mkdir_p(self.VIMPYRE_PATH)
@@ -83,6 +90,8 @@ class Bat(object):
                 console('Catch done! Please add the following to your .vimrc:')
                 console('call pathogen#runtime_append_all_bundles("vimpyre")')
             else:
+                console('Pathogen vimscript not found in %s' % self.pathogen_url)
+                console('You can change this url with enviroment variable VIM_PATHOGEN_URL')
                 console('Catch fail! Please try again!')
         except:
             console('[Unexpected Error] Catch fail! Please try again!')
